@@ -192,7 +192,8 @@ def serve_application(
     protocol = "https" if ssl_context else "http"
 
     logger.info(
-        f"Starting Rasa server on {constants.DEFAULT_SERVER_FORMAT.format(protocol, port)}"
+        f"Starting Rasa server on "
+        f"{constants.DEFAULT_SERVER_FORMAT.format(protocol, port)}"
     )
 
     app.register_listener(
