@@ -290,12 +290,13 @@ class LexicalSyntacticFeaturizer(SparseFeaturizer):
         feature_to_idx_file = Path(model_dir) / f"{file_name}.feature_to_idx_dict.pkl"
         feature_to_idx_dict = io_utils.json_unpickle(feature_to_idx_file)
 
-        return LexicalSyntacticFeaturizer(meta, feature_to_idx_dict=feature_to_idx_dict)
+        return cls(meta, feature_to_idx_dict=feature_to_idx_dict)
 
     def persist(self, file_name: Text, model_dir: Text) -> Optional[Dict[Text, Any]]:
         """Persist this model into the passed directory.
-        Return the metadata necessary to load the model again."""
 
+        Return the metadata necessary to load the model again.
+        """
         feature_to_idx_file = Path(model_dir) / f"{file_name}.feature_to_idx_dict.pkl"
         io_utils.json_pickle(feature_to_idx_file, self.feature_to_idx_dict)
 
